package WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST;
$WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST::VERSION = '0.000001';
use Moo;

# The logic for these two classes is exactly the same.  We subclass rather than
# using roles so that we don't have to duplicate the BUILD method.

extends 'WebService::PayPal::PaymentsAdvanced::Response::FromRedirect';

1;

=pod

=encoding UTF-8

=head1 NAME

WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST - Parse Payments Advanced response params which originate from a silent POST

=head1 VERSION

version 0.000001

=head1 DESCRIPTION

This module has the same internals and public interface as
L<WebService::PayPal::PaymentsAdvanced::Response::FromRedirect>.

=head1 AUTHOR

Olaf Alders <olaf@wundercounter.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2015 by MaxMind, Inc..

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut

__END__
# ABSTRACT: Parse Payments Advanced response params which originate from a silent POST

